@@ -72,7 +72,16 @@ pub fn create_trace_listener(
                 writers.push(Box::new(stdout()));
             }
 
-            return CompositeWriter::new(writers);
+            let mut composite_writer = CompositeWriter::new(writers);
+
+            composite_writer
+                .write_all("\n\n".as_bytes())
+                .expect("Cannot write to composite writer.");
+
+            composite_writer.flush()
+                .expect("Cannot flush composite writer.");
+
+            return composite_writer;
          })
         .init();
 }
